<template>
    <div class="login-container">
        <div class="wxLogin">
            <el-card class="main_wx">
                <wxlogin :appid="appid" :redirect_uri="redirect_uri" scope="snsapi_login" :href="href" :state="state">
                </wxlogin>
            </el-card>
        </div>
    </div>
</template>

<script>
import { validUsername } from "@/utils/validate";
import wxlogin from "vue-wxlogin";
import { login } from "@/api/user";
import { findStaffByUserId } from "@/api/staff";
export default {
    name: "Login",
    components: { wxlogin },
    data() {
        const validateUsername = (rule, value, callback) => {
            if (!validUsername(value)) {
                callback(new Error("Please enter the correct user name"));
            } else {
                callback();
            }
        };
        const validatePassword = (rule, value, callback) => {
            if (value.length < 6) {
                callback(new Error("The password can not be less than 6 digits"));
            } else {
                callback();
            }
        };
        return {
            appid: "wx7103925df6236723",
            redirect_uri: encodeURIComponent("https://dingdang.9village.cn/#/login"),
            state: "1",
            href: "data:text/css;base64,LmltcG93ZXJCb3ggLnFyY29kZSB7d2lkdGg6IDIwMHB4O30KLmltcG93ZXJCb3ggLnRpdGxlIHtkaXNwbGF5OiBub25lO30KLmltcG93ZXJCb3ggLmluZm8ge3dpZHRoOiAyMDBweDt9Ci5zdGF0dXNfaWNvbiB7ZGlzcGxheTogbm9uZX0KLmltcG93ZXJCb3ggLnN0YXR1cyB7dGV4dC1hbGlnbjogY2VudGVyO30g", // 自定义样式链接
            loginForm: {
                username: "admin",
                password: "111111",
            },
            loginRules: {
                username: [
                    { required: true, trigger: "blur", validator: validateUsername },
                ],
                password: [
                    { required: true, trigger: "blur", validator: validatePassword },
                ],
            },
            loading: false,
            passwordType: "password",
            redirect: undefined,
        };
    },
    watch: {
        $route: {
            handler: function (route) {
                this.redirect = route.query && route.query.redirect;
            },
            immediate: true,
        },
    },
    beforeRouteUpdate(route, from, next) {
        this.redirect = route.query && route.query.redirect;
        let code = route.query.code;
        if (code) {
            this.getUserDate(code);
        } else {
            this.getWeChatUrl();
        }
    },
    mounted() {
        let code = this.$route.query.code;
        if (code) {
            this.getUserDate(code);
        } else {
            this.getWeChatUrl();
        }
    },
    methods: {
        getUserDate(code) {
            login({
                code: code,
            }).then((res) => {
                localStorage.setItem("user", JSON.stringify(res));
                localStorage.setItem("staffs", JSON.stringify(res.staffs));
                localStorage.setItem("selectStaff", JSON.stringify(res.staffs[0]));

                // 判断是否为叮当管理员账号
                var isAdmin = false
                res.staffs.forEach(o => {
                    if (o.org.orgType === "PLATFORM") {
                        isAdmin = true;
                    }
                })
                if (isAdmin) {
                    findStaffByUserId(res.id).then(staffs => {
                        localStorage.setItem("staffs", JSON.stringify(staffs));
                        localStorage.setItem("selectStaff", JSON.stringify(staffs[0]));
                    })
                }

                this.$router.push("/student");
            });
        },
        getWeChatUrl() {
            // api.wachatQrUrl().then(res => {
            //   if (res && res.code === '0000') {
            //     const data = res.data
            //     this.appid = data.appId
            //     this.redirect_uri = data.wxCallbackUrl + 'weChatLogin'
            //   }
            // })
        },
        showPwd() {
            if (this.passwordType === "password") {
                this.passwordType = "";
            } else {
                this.passwordType = "password";
            }
            this.$nextTick(() => {
                this.$refs.password.focus();
            });
        },
        handleLogin() {
            this.$router.push({ path: "/educational/student" });
            // this.$refs.loginForm.validate((valid) => {
            //   if (valid) {
            //     this.loading = true;
            //     this.$store
            //       .dispatch("user/login", this.loginForm)
            //       .then(() => {
            //         this.$router.push({ path: this.redirect || "/" });
            //         this.loading = false;
            //       })
            //       .catch(() => {
            //         this.loading = false;
            //       });
            //   } else {
            //     console.log("error submit!!");
            //     return false;
            //   }
            // });
        },
    },
};
</script>

<style lang="scss">
/* 修复input 背景不协调 和光标变色 */
/* Detail see https://github.com/PanJiaChen/vue-element-admin/pull/927 */

$bg: #283443;
$light_gray: #fff;
$cursor: #fff;

@supports (-webkit-mask: none) and (not (cater-color: $cursor)) {
    .login-container .el-input input {
        color: $cursor;
    }
}

/* reset element-ui css */
.login-container {
    background-image: url('../../assets/login_backgroup.png');
    // background-size: contain;
    background-size: auto 100%;
    background-position: center center;
    /* 背景图不平铺 */
    background-repeat: no-repeat;
    /* 当内容高度大于图片高度时，背景图像的位置相对于viewport固定 */
    background-attachment: fixed;
    display: flex;
    align-items: center;
    justify-content: center;

    .el-input {
        display: inline-block;
        height: 47px;
        width: 85%;

        input {
            background: transparent;
            border: 0px;
            -webkit-appearance: none;
            border-radius: 0px;
            padding: 12px 5px 12px 15px;
            color: $light_gray;
            height: 47px;
            caret-color: $cursor;

            &:-webkit-autofill {
                box-shadow: 0 0 0px 1000px $bg inset !important;
                -webkit-text-fill-color: $cursor !important;
            }
        }
    }

    .el-form-item {
        border: 1px solid rgba(255, 255, 255, 0.1);
        background: rgba(0, 0, 0, 0.1);
        border-radius: 5px;
        color: #454545;
    }
}

#weixin {
    /* background-color: #fcf; */
    display: flex;
    justify-content: center;
    margin-top: -20px;
}
</style>

<style lang="scss" scoped>
$bg: #ffffff;
$dark_gray: #889aa4;
$light_gray: #eee;

.login-container {
    min-height: 100%;
    width: 100%;
    background-color: $bg;
    overflow: hidden;

    .login-form {
        position: relative;
        width: 520px;
        max-width: 100%;
        padding: 160px 35px 0;
        margin: 0 auto;
        overflow: hidden;
    }

    .tips {
        font-size: 14px;
        color: #fff;
        margin-bottom: 10px;

        span {
            &:first-of-type {
                margin-right: 16px;
            }
        }
    }

    .svg-container {
        padding: 6px 5px 6px 15px;
        color: $dark_gray;
        vertical-align: middle;
        width: 30px;
        display: inline-block;
    }

    .title-container {
        position: relative;

        .title {
            font-size: 26px;
            color: $light_gray;
            margin: 0px auto 40px auto;
            text-align: center;
            font-weight: bold;
        }
    }

    .show-pwd {
        position: absolute;
        right: 10px;
        top: 7px;
        font-size: 16px;
        color: $dark_gray;
        cursor: pointer;
        user-select: none;
    }
}

.main_wx {
    height: 360px;
    margin-bottom: 100px;
}
</style>
